@@ -14,7 +14,8 @@
 #define NUM_STARS 1500
 #define LOGO_ALPHA_PERCENTAGE 71
 #define STARSHINE_ALPHA_PERCENTAGE 33
-#define SINUS_PHASES 1024
+#define SIN_PHASES 1024
+#define SIN_MASK (SIN_PHASES-1)
 #define ABOUT_SCREEN_X 3
 #define ABOUT_SCREEN_Y 3
 #define ABOUT_SCREEN_W 626
@@ -54,11 +55,11 @@ static char *customText2 = "https://16-bits.org";
 static char customText3[256];
 static int16_t customText0X, customText0Y, customText1Y, customText2Y;
 static int16_t customText3Y, customText1X, customText2X, customText3X;
-static int16_t sin16[SINUS_PHASES], zSpeed;
+static int16_t sin32767[SIN_PHASES+(SIN_PHASES/4)], *cos32767, zSpeed;
 static int32_t lastStarScreenPos[OLD_NUM_STARS];
 static const uint16_t logoAlpha16 = (65535 * LOGO_ALPHA_PERCENTAGE) / 100;
 static const uint16_t starShineAlpha16 = (65535 * STARSHINE_ALPHA_PERCENTAGE) / 100;
-static uint32_t sinp1, sinp2;
+static uint32_t sinp, cosp;
 static oldVector_t oldStarPoints[OLD_NUM_STARS];
 static oldRotate_t oldStarRotation;
 static oldMatrix_t oldStarMatrix;
@@ -90,13 +91,12 @@ static void blendPixelsXY(uint32_t x, uint32_t y, uint32_t pixelB_r, uint32_t pi
 
 static void oldRotateStarfieldMatrix(void)
 {
-	// original code used a cos/sin table, but this only runs once per frame, no need...
-	const int16_t sa = (int16_t)round(32767.0 * sin(oldStarRotation.x * (2.0 * PI / 65536.0)));
-	const int16_t ca = (int16_t)round(32767.0 * cos(oldStarRotation.x * (2.0 * PI / 65536.0)));
-	const int16_t sb = (int16_t)round(32767.0 * sin(oldStarRotation.y * (2.0 * PI / 65536.0)));
-	const int16_t cb = (int16_t)round(32767.0 * cos(oldStarRotation.y * (2.0 * PI / 65536.0)));
-	const int16_t sc = (int16_t)round(32767.0 * sin(oldStarRotation.z * (2.0 * PI / 65536.0)));
-	const int16_t cc = (int16_t)round(32767.0 * cos(oldStarRotation.z * (2.0 * PI / 65536.0)));
+	const int16_t sa = sin32767[oldStarRotation.x >> 6];
+	const int16_t ca = cos32767[oldStarRotation.x >> 6];
+	const int16_t sb = sin32767[oldStarRotation.y >> 6];
+	const int16_t cb = cos32767[oldStarRotation.y >> 6];
+	const int16_t sc = sin32767[oldStarRotation.z >> 6];
+	const int16_t cc = cos32767[oldStarRotation.z >> 6];
 
 	oldStarMatrix.x.x = ((ca * cc) >> 16) + (((sc * ((sa * sb) >> 16)) >> 16) << 1);
 	oldStarMatrix.y.x = (sa * cb) >> 16;
@@ -266,8 +266,8 @@ void renderAboutScreenFrame(void)
 		{
 			for (int32_t x = 0; x < ABOUT_SCREEN_W; x++)
 			{
-				int32_t srcX = (x - ((ABOUT_SCREEN_W-ABOUT_LOGO_W)/2))    + (sin16[(sinp1+x)     & (SINUS_PHASES-1)] >> 10);
-				int32_t srcY = (y - ((ABOUT_SCREEN_H-ABOUT_LOGO_H)/2)+20) + (sin16[(sinp2+y+x+x) & (SINUS_PHASES-1)] >> 11);
+				int32_t srcX = (x - ((ABOUT_SCREEN_W-ABOUT_LOGO_W)/2))    + (sin32767[(sinp+x)     & SIN_MASK] >> 10);
+				int32_t srcY = (y - ((ABOUT_SCREEN_H-ABOUT_LOGO_H)/2)+20) + (cos32767[(cosp+y+x+x) & SIN_MASK] >> 11);
 
 				if ((uint32_t)srcX < ABOUT_LOGO_W && (uint32_t)srcY < ABOUT_LOGO_H)
 				{
@@ -278,8 +278,8 @@ void renderAboutScreenFrame(void)
 			}
 		}
 
-		sinp1 = (sinp1 + 2) & (SINUS_PHASES-1);
-		sinp2 = (sinp2 + 3) & (SINUS_PHASES-1);
+		sinp = (sinp + 2) & SIN_MASK;
+		cosp = (cosp + 3) & SIN_MASK;
 
 		// render static texts
 		textOut(customText0X, customText0Y, PAL_FORGRND, customText0);
@@ -376,15 +376,11 @@ void showAboutScreen(void) // called once when about screen is opened
 				{
 					int32_t r = (int32_t)round(sqrt(randoml(500) * 500));
 					int32_t w = randoml(3000);
-					double ww = ((w * 8) + r) * (1.0 / 16.0);
+					int32_t h = cos32767[((8*w+r) / 16) & SIN_MASK] / 4;
 
-					const int16_t z =  (int16_t)round(32767.0 * cos(w  * (2.0 * PI / 1024.0)));
-					const int16_t y =  (int16_t)round(32767.0 * sin(w  * (2.0 * PI / 1024.0)));
-					const int16_t x = ((int16_t)round(32767.0 * cos(ww * (2.0 * PI / 1024.0)))) / 4;
-
-					s->z = (int16_t)((z * (w + r)) / 3500);
-					s->y = (int16_t)((y * (w + r)) / 3500);
-					s->x = (int16_t)((x * r) / 500);
+					s->z = (int16_t)((cos32767[w & SIN_MASK] * (w + r)) / 3500);
+					s->y = (int16_t)((sin32767[w & SIN_MASK] * (w + r)) / 3500);
+					s->x = (int16_t)((h * r) / 500);
 				}
 			}
 			break;
@@ -416,12 +412,12 @@ void initAboutScreen(void)
 		s->z = (float)((randoml(INT32_MAX) - (INT32_MAX/2)) * (1.0 / INT32_MAX));
 	}
 
-	sinp1 = 0;
-	sinp2 = SINUS_PHASES / 4; // cosine offset
+	sinp = cosp = 0;
 
-	// pre-calc sinus table
-	for (int32_t i = 0; i < SINUS_PHASES; i++)
-		sin16[i] = (int16_t)round(32767.0 * sin(i * PI * 2.0 / SINUS_PHASES));
+	// pre-calc sin/cos table
+	for (int32_t i = 0; i < SIN_PHASES + (SIN_PHASES / 4); i++)
+		sin32767[i] = (int16_t)round(32767.0 * sin(i * (PI * 2.0 / SIN_PHASES)));
+	cos32767 = &sin32767[SIN_PHASES / 4];
 
 	sprintf(customText3, "v%s (%s)", PROG_VER_STR, PROG_VER_DATE);
 
