@@ -12,8 +12,8 @@
 #endif
 #include "ft2_replayer.h"
 
-#define PROG_VER_STR "2.03"
-#define PROG_VER_DATE "14 December 2025"
+#define PROG_VER_STR "2.04"
+#define PROG_VER_DATE "11 February 2026"
 
 // do NOT change these! It will only mess things up...
 
